//
//  ErrorProvider.swift
//  Trampigo
//
//  Created by Naim Ashhab on 21.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import Foundation

// MARK: - General protocol
protocol GeneralErrorType: ErrorType {
  func localizedMessage() -> String
}

extension GeneralErrorType where Self: RawRepresentable, Self.RawValue == String {
  func localizedMessage() -> String {
    return self.rawValue.localized
  }
}

// MARK: - Error provider class
class ErrorProvider {
  
  class func errorByCode(code: Int) -> GeneralErrorType! {
    
    switch code {
      
      
      // General
      
    case -1:
      return GeneralError.ServerOutOfService
    case 999:
      return GeneralError.BadAPIEndpoint
      
      
      // User
      
    case 1001:
      return UserError.NotSignedUp
    case 1002:
      return UserError.SignedUp
    case 1003:
      return UserError.WrongPassword
    case 1004:
      return UserError.EmptySearchTerm
    case 1005:
      return UserError.EditEmptyEmail
    case 1006:
      return UserError.EditEmptyName
    case 1007:
      return UserError.WrongOriginPassword
      
      
      // Training
      
    case 2001:
      return TrainingError.UnfinishedTraining
    case 2002:
      return TrainingError.MissingDatePrameter
    case 2003:
      return TrainingError.NoResultByID
    case 2004:
      return TrainingError.GetNotAuthorized
      
      // Access token errors
      
    case 8001:
      return AccessTokenError.NotMatching
    case 8002:
      return AccessTokenError.Missing
      
      
      // Empty fields
      
    case 9001:
      return EmptyFieldError.Email
    case 9002:
      return EmptyFieldError.Password
    case 9003:
      return EmptyFieldError.FullName
    case 9004:
      return EmptyFieldError.Role
      
      
      // Wrong format
      
    case 9101:
      return WrongFormatError.Email
    case 9102:
      return WrongFormatError.Role
      
    default:
      return GeneralError.Unknown
    }
    
  }
  
}


// MARK: - General
enum GeneralError: String, GeneralErrorType {
  
  case Unknown = "unknown-error"
  case NoAck = "no-ack"
  case ServerOutOfService = "server-out-of-service"
  case BadAPIEndpoint = "bad-api-endpoint"
  case ServerBadEmitAck = "server-bad-emit-ack"
  
}

// MARK: - User
enum UserError: String, GeneralErrorType {
  
  case NotSignedUp = "user-not-signed-up"
  case SignedUp = "user-signed-up"
  case WrongPassword = "user-wrong-password"
  case EmptySearchTerm = "user-search-empty-term"
  case EditEmptyEmail = "user-edit-empty-email"
  case EditEmptyName = "user-edit-empty-name"
  case WrongOriginPassword = "user-old-password-wrong"
  
}

// MARK: - Training
enum TrainingError: String, GeneralErrorType {
  
  case UnfinishedTraining = "training-unfinished"
  case MissingDatePrameter = "training-missing-date"
  case NoResultByID = "training-no-result-id"
  case GetNotAuthorized = "training-get-not-authorized"
  
}

// MARK: - Access token
enum AccessTokenError: String, GeneralErrorType {
  
  case NotMatching = "access-token-not-matching"
  case Missing = "access-token-missing"
  
}

// MARK: - Empty field
enum EmptyFieldError: String, GeneralErrorType {
  
  case Email = "empty-field-email"
  case Password = "empty-field-password"
  case FullName = "empty-field-full-name"
  case Role = "empty-field-role"
  
}

// MARK: - Wrong format
enum WrongFormatError: String, GeneralErrorType {
  
  case Email = "wrong-format-email"
  case Role = "wrong-format-role"
  
}
