//
//  TimeRange.swift
//  Trampigo
//
//  Created by Naim Ashhab on 16.12.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import Foundation

struct TimeRange {
  
  var from  : NSDate!
  var to    : NSDate!
  var days  : Int
  var daysToPast: Int
  
  private let secondsInDay = 24 * 60 * 60
  private var infinite: Bool = false
  
  init(rangeDays: Int = 7, daysToPast: Int = 0) {
    
    days = rangeDays
    self.daysToPast = daysToPast
    
    self.countDates()
  }
  
  private init(infinite: Bool) {
    self.infinite = infinite
    
    days = 0
    daysToPast = 0
  }
  
  static var infinite: TimeRange {
    return TimeRange(infinite: true)
  }
  
  
  var isInfinite: Bool {
    return self.infinite
  }
  
  func toDateArray() -> [NSDate] {
    
    var dates = [NSDate]()
    
    for index in 0..<days {
      dates.append(NSDate(timeInterval: Double(index * secondsInDay), sinceDate: from).dayDate()!)
    }
    
    return dates
  }
  
  mutating func setDayRange(days: Int) {
    self.days = days
    
    self.countDates()
  }
  
  mutating func setDaysToPast(daysToPast: Int) {
    self.daysToPast = daysToPast
    
    self.countDates()
  }
  
  
  private mutating func countDates() {
    to = NSDate(timeIntervalSinceNow: -Double(secondsInDay * daysToPast))
    from = NSDate(timeInterval: -Double(secondsInDay * (days-1)), sinceDate: to)
  }
  
}
