//
//  TrainingEmit.swift
//  Trampigo
//
//  Created by Naim Ashhab on 19.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import Foundation

enum TrainingEmit: APIEmit {
  
  case Add(training: Training) // Create & upload new training
  case Edit(training: Training) // Edit date, time or duration of training
  case Delete(training: Training) // Delete existing training
  case List(id: String, from: NSDate, to: NSDate) // Get trainings from - to
  case GetOne(trainingID: String) // Get one specific training by ID
  case Running(userIds: [String]) // Confirm if user has running training or not
  
  // Real-time
  case Start(training: Training) // Create & run new training. In ack returns training ID.
  case Finished(training: Training) // Finish & save running training
  case Canceled(training: Training) // Cancel & delete running training
  case AddRound(training: Training, round: Round) // Add new round to running training. In ack returns round ID.
  case EditRound(training: Training, index: Int, round: Round) // Edit round in running or finished training
  case MoveRound(training: Training, from: Int, to: Int) // Change round position in training
  case DeleteRound(training: Training, index: Int) // Delete round from running or finished training
  
  func eventName() -> String {
    
    var eventName = "training/"
    
    switch self {
      
    case .Add:
      eventName += "add"
    case .Edit:
      eventName += "edit"
    case .Delete:
      eventName += "delete"
    case .List:
      eventName += "list"
    case .GetOne:
      eventName += ""
    case .Running:
      eventName += "running"
      
      // Real-time
    case .Start:
      eventName += "start"
    case .Finished:
      eventName += "finish"
    case .Canceled:
      eventName += "cancel"
    case .AddRound:
      eventName += "add/round"
    case .EditRound:
      eventName += "edit/round"
    case .MoveRound:
      eventName += "move/round"
    case .DeleteRound:
      eventName += "delete/round"
    }
    
    
    return eventName
  }
  
  func items() -> AnyObject {
    
    switch self {
      
    case .Add(let training): return [
      "training"  : training] // TODO:
    case .Edit(let training): return [
      "id"        : training.id,
      "date"      : training.date.timeIntervalSince1970,
      "duration"  : training.duration]
    case .Delete(let training): return [
      "id"        : training.id]
    case .List(let id, let from, let to): return [
      "id"        : id,
      "from"      : from.timeIntervalSince1970,
      "to"        : to.timeIntervalSince1970]
    case .GetOne(let trainingID): return [
      "id"        : trainingID]
    case .Running(let userIds): return [
      "ids"       : userIds]
      
    case .Start(let training)   : return [
      "date"      : training.date.timeIntervalSince1970]
    case .Finished(let training): return [
      "id"        : training.id]
    case .Canceled(let training): return [
      "id"        : training.id]
    case .AddRound(let training, let round): return [
      "id"        : training.id,
      "skills"    : round.skills,
      "difficulty": round.difficulty]
    case .EditRound(let training, let index, let round): return [
      "id"        : training.id,
      "skills"    : round.skills,
      "difficulty": round.difficulty,
      "index"     : index]
    case .MoveRound(let training, let from, let to): return [
      "id"        : training.id,
      "from"      : from,
      "to"        : to]
      
    case .DeleteRound(let training, let index): return [
      "id"        : training.id,
      "index"     : index]
      
    }
  }
  
}