//
//  Parser.swift
//  Trampigo
//
//  Created by Naim Ashhab on 03.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit
import SwiftyJSON
import Alamofire

// MARK: - HTTP protocol

protocol APIRequest {
  
  func apiURL() -> String
  func apiParams() -> [String: AnyObject]?
  func apiHeaderParams() -> [String: String]?
  func apiMethod() -> Alamofire.Method
  
}

typealias GeneralOnReturnBlock = (status: Bool, data: JSON?, error: GeneralErrorType?) -> Void
typealias GeneralAPIError = (code: Int, message: String)


// MARK: - Parser

final class Parser {
  
  static let sharedInstance = Parser()
  
  class func makeRequest(apiRequest: APIRequest, onReturn: GeneralOnReturnBlock?) -> Request {
    
    var headers: [String: String] = apiRequest.apiHeaderParams() ?? [:]
    if let accessToken = User.logedUser?.accessToken {
      headers.updateValue(accessToken, forKey: "x-access-token")
    }
    
    return request(apiRequest.apiMethod(),
      serverAPIURL + apiRequest.apiURL(),
      parameters: apiRequest.apiParams(),
      encoding: .JSON,
      headers: headers
      ).responseSwiftyJSON({ (_, _, json, error) -> Void in
        
        if let status = json["status"].bool {
          
          if status {
            onReturn?(status: true, data: json["data"], error: nil)
          }
          else if json["error"] != JSON.null {
            
            let errCode = json["error"]["code"].intValue
            onReturn?(status: false, data: nil, error: ErrorProvider.errorByCode(errCode))
            
            print("Error: \(errCode): " + json["error"]["message"].stringValue)
          }
          else {
            assert(false, "Server returned wrong format response")
          }
          
        }
        else {
          onReturn?(status: false, data: nil, error: ErrorProvider.errorByCode(-1))
        }
        
      })
    
  }
  
}
