//
//  UserRequests.swift
//  Trampigo
//
//  Created by Naim Ashhab on 03.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import Foundation
import Alamofire

enum UserHTTPRequest: APIRequest {
  
  case Login(email: String, password: String)
  case SignUp(email: String, password: String, fullName: String)
  case Me(accessToken: String)
  
  func apiURL() -> String {
    
    var url = "/user"
    
    switch self {
    case .Login:
      url += "/login"
      
    case .SignUp:
      url += "/signup"
      
    case Me:
      url += "/me"
      
    }
    
    return url
  }
  
  func apiParams() -> [String : AnyObject]? {
    
    switch self {
    case .Login(let email, let password):
      return ["email": email, "password": password, "role": isGymnastTarget ? "gymnast" : "coach"]
      
    case .SignUp(let email, let password, let fullName):
      return ["email": email, "password": password, "fullName": fullName, "role": isGymnastTarget ? "gymnast" : "coach"]
      
    default:
      return nil
    }
    
  }
  
  func apiHeaderParams() -> [String : String]? {
    
    switch self {
     
    case .Me(let accessToken):
      return ["x-access-token": accessToken]
      
    default:
      return nil
    }
    
  }
  
  func apiMethod() -> Alamofire.Method {
    
    switch self {
    case .Login, SignUp:
      return .POST
      
    case .Me:
      return .GET
      
    }
    
  }
  
}