//
//  NSDateExt.swift
//  Trampigo
//
//  Created by Naim Ashhab on 09.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import Foundation

extension NSDate {
  
  struct SharedInstance {
    static var instance = NSDateFormatter()
  }
  
  class var sharedFormatter: NSDateFormatter! {
    get {
    return SharedInstance.instance
    }
    set {
      SharedInstance.instance = newValue
    }
  }
  
  func time() -> String {
    defer {
      NSDate.setFormatterToDefaultValues()
    }
    
    NSDate.sharedFormatter.timeStyle = .ShortStyle
    NSDate.sharedFormatter.dateStyle = .NoStyle
    
    return NSDate.sharedFormatter.stringFromDate(self)
  }
  
  func date() -> String {
    defer {
      NSDate.setFormatterToDefaultValues()
    }
    
    NSDate.sharedFormatter.timeStyle = .NoStyle
    NSDate.sharedFormatter.dateStyle = .MediumStyle
    
    return NSDate.sharedFormatter.stringFromDate(self)
  }
  
  func day() -> String {
    defer {
      NSDate.setFormatterToDefaultValues()
    }
    
    NSDate.sharedFormatter.dateFormat = "eeee"
    
    return NSDate.sharedFormatter.stringFromDate(self)
  }
  
  func dayDate() -> NSDate? {
    
    let flags: NSCalendarUnit =  [.Year, .Month, .Day]
    let calendar = NSCalendar.currentCalendar()
    let components = calendar.components(flags, fromDate: self)
    
    return calendar.dateFromComponents(components)
  }
  
  
  private class func setFormatterToDefaultValues() {
    NSDate.sharedFormatter.timeStyle = .ShortStyle
    NSDate.sharedFormatter.dateStyle = .ShortStyle
  }
  
}

@warn_unused_result func ==(left: NSDate, right: NSDate) -> Bool {
  return left.compare(right) == .OrderedSame
}
@warn_unused_result func !=(left: NSDate, right: NSDate) -> Bool {
  return left.compare(right) != .OrderedSame
}
@warn_unused_result func <(left: NSDate, right: NSDate) -> Bool {
  return left.compare(right) == .OrderedAscending
}
@warn_unused_result func >(left: NSDate, right: NSDate) -> Bool {
  return left.compare(right) == .OrderedDescending
}
