//
//  UIKitExt.swift
//  Trampigo
//
//  Created by Naim Ashhab on 10.12.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit

// MARK: - ViewController

extension UIViewController {
  
  @IBAction func dismissViewController() {
    self.dismissViewControllerAnimated(true, completion: nil)
  }
  
  func registerForSocketConnectionNotifications(connectionChangedSelector selector: Selector) {
    NSNotificationCenter.defaultCenter().addObserver(self, selector: selector, name: SocketNotification.ConnectionChanged.rawValue, object: nil)
  }
  
}


// MARK: - NavigationBar

extension UINavigationBar {
  
//  override public func sizeThatFits(size: CGSize) -> CGSize {
//    return CGSize(width: UIScreen.mainScreen().bounds.width, height: 60.0) // Custom navigation bar height
//  }
  
}


// MARK: - Color

extension UIColor {
  
  // MARK: Primary & secondary
  
  class func trampigoPrimaryColor() -> UIColor {
    return UIColor.colorFromHEX(isGymnastTarget ? "#102770" : "#910012")
  }
  
  class func trampigoSecondaryColor() -> UIColor {
    return UIColor.colorFromHEX(isGymnastTarget ? "#22A7F0" : "#000000") // TODO: make coach secondary color
  }
  
  
  // MARK: Elements
  
  class func trampigoDifficultyColor() -> UIColor {
    return UIColor.colorFromHEX("#102770")
  }
  
  class func trampigoDifficultyPerSkillColor() -> UIColor {
    return UIColor.colorFromHEX("#C0392B")
  }
  
  class func trampigoSkillsColor() -> UIColor {
    return UIColor.colorFromHEX("#F39C12")
  }
  
  class func trampigoRoundsColor() -> UIColor {
    return UIColor.colorFromHEX("#34495E")
  }
  
  class func trampigoTrainingsColor() -> UIColor {
    return UIColor.trampigoDifficultyColor()
  }
  
  // MARK: Helper
  
  class func colorFromHEX (hex:String, andAlpha alpha: CGFloat = 1.0) -> UIColor {
    var cString = hex.stringByTrimmingCharactersInSet(NSCharacterSet.whitespaceAndNewlineCharacterSet()).uppercaseString as NSString
    
    if (cString.hasPrefix("#")) {
      cString = cString.substringFromIndex(1)
    }
    
    if (cString.length != 6) {
      return UIColor.grayColor()
    }
    
    let rString = cString.substringToIndex(2)
    let gString = (cString.substringFromIndex(2) as NSString).substringToIndex(2)
    let bString = (cString.substringFromIndex(4) as NSString).substringToIndex(2)
    
    var r:CUnsignedInt = 0, g:CUnsignedInt = 0, b:CUnsignedInt = 0;
    NSScanner(string:rString).scanHexInt(&r)
    NSScanner(string:gString).scanHexInt(&g)
    NSScanner(string:bString).scanHexInt(&b)
    
    return UIColor(red: CGFloat(r) / 255.0, green: CGFloat(g) / 255.0, blue: CGFloat(b) / 255.0, alpha: CGFloat(1)).colorWithAlphaComponent(alpha)
    
  }
  
}


// MARK: - Image

extension UIImage {
  
  func imageWithImageSize(size: CGSize) -> UIImage {
    
    UIGraphicsBeginImageContext(size)
    self.drawInRect(CGRect(origin: CGPoint(x: 0, y: 0), size: size))
    let resizedImage = UIGraphicsGetImageFromCurrentImageContext()
    UIGraphicsEndImageContext()
    
    return resizedImage
    
  }
  
}