//
//  LoginVC.swift
//  Trampigo
//
//  Created by Naim Ashhab on 03.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit

typealias UserFieldData = (placeholder: String, keyboardType: UIKeyboardType, secured: Bool)

final class LoginSignUpVC: UIViewController {
  
  // MARK: - Outlets
  
  @IBOutlet weak var logo: UIImageView!
  @IBOutlet weak var closeButton: UIButton!
  
  @IBOutlet weak var mainScrollView       : UIScrollView!
  @IBOutlet weak var separatorLabel       : UILabel!
  @IBOutlet weak var customNavigationBar  : UIView!
  @IBOutlet weak var loginSignUpButton    : SlantButton!
  @IBOutlet weak var fieldStack           : UIStackView!
  
  @IBOutlet var fields: [UITextField]!
  
  @IBOutlet weak var fullNameField      : UITextField!
  @IBOutlet weak var emailField         : UITextField!
  @IBOutlet weak var passwordField      : UITextField!
  
  // MARK: - Property
  
  var login: Bool = false // If true -> Login else -> Sign Up
  
  // MARK: - Lifecycle
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    setupView()
  }
  
  override func viewWillAppear(animated: Bool) {
    super.viewWillAppear(animated)
    
    // Register keyboard notifications
    NSNotificationCenter.defaultCenter().addObserver(self, selector: "didShowKeyboard:", name: UIKeyboardDidShowNotification, object: nil)
    NSNotificationCenter.defaultCenter().addObserver(self, selector: "willHideKeyboard:", name: UIKeyboardWillHideNotification, object: nil)
  }
  
  override func viewWillDisappear(animated: Bool) {
    super.viewWillDisappear(animated)
    
    NSNotificationCenter.defaultCenter().removeObserver(self)
  }
  
  // MARK: - Actions
  
  @IBAction func loginWithFB(sender: AnyObject) {
    print("Not implemented yet")
  }
  
  @IBAction func loginWithTwitter(sender: AnyObject) {
    print("Not implemented yet")
  }
  
  @IBAction func loginSignUp(sender: AnyObject) {
    proccessLoginSignUp()
  }
  
  // MARK: - Selectors
  
  // MARK: - Private
  
  private func proccessLoginSignUp() {
    
    let onReturn: (user: User!, error: GeneralErrorType?) -> Void = {
      (user, error) -> Void in
      
      if let _ = user {
        self.dismissViewController()
      }
      else {
        dump(error!.localizedMessage())
        // TODO: show error message
      }
      
      self.loginSignUpButton.indicatingActivity = false
    }
    
    if isFormValid {
      
      loginSignUpButton.indicatingActivity = true
      
      let userType: User.Type = isGymnastTarget ? Gymnast.self : Coach.self
      if login {
        userType.loginUser(emailField.text!, password: passwordField.text!, onReturn: onReturn)
      } else {
        userType.signUpUser(emailField.text!, fullName: fullNameField.text!, password: passwordField.text!, onReturn: onReturn)
      }
      
    } else {
      // TODO: Show valid form error
    }
  }
  
  private func setupView() {
    
    // Texts
    
    separatorLabel.text = "  " + "or".localized + "  "
    
    
    // Buttons
    
    loginSignUpButton.backgroundColor = UIColor.trampigoPrimaryColor()
    loginSignUpButton.setTitle(login ? "Login".localized : "Sign Up".localized, forState: .Normal)
    
    closeButton.tintColor = UIColor.trampigoPrimaryColor()
    
    
    // Fields
    
    if login {
      fields.removeAtIndex(0).removeFromSuperview()
    }
    
    for field in fields {
      field.delegate = self
      field.tintColor = UIColor.trampigoPrimaryColor()
      field.textColor = UIColor.trampigoPrimaryColor()
    }
    
    
    // Logo
    
    logo.image = getLogo()
  }
  
}

// MARK: - Keyboard notifications
extension LoginSignUpVC {
  
  func didShowKeyboard(notification: NSNotification) {
    
    if let keyboardSize = (notification.userInfo?[UIKeyboardFrameEndUserInfoKey] as? NSValue)?.CGRectValue() {
      let contentInsets = UIEdgeInsets(top: 0, left: 0, bottom: keyboardSize.height, right: 0)
      self.mainScrollView.contentInset = contentInsets
      
      var responderField: UITextField!
      for field in fields {
        if field.isFirstResponder() {
          responderField = field
          break
        }
      }
      
      if responderField != nil {
        self.mainScrollView.scrollRectToVisible(responderField.frame, animated: true)
      }
      
    }
    
  }
  
  func willHideKeyboard(notification: NSNotification) {
    self.mainScrollView.contentInset = UIEdgeInsetsZero
  }
}

// MARK: - Text field delegate
extension LoginSignUpVC : UITextFieldDelegate {
  
  var isFormValid: Bool {
    
    if emailField.text?.isEmpty ?? true {
      return false
    }
    
    if passwordField.text?.isEmpty ?? true {
      return false
    }
    
    if !login && fullNameField.text?.isEmpty ?? true  {
      return false
    }
    
    return true
  }
  
  func textField(textField: UITextField, shouldChangeCharactersInRange range: NSRange, replacementString string: String) -> Bool {
    
    
    
    return true
  }
  
  func textFieldShouldReturn(textField: UITextField) -> Bool {
    
    if let fieldIndex = self.fields.indexOf(textField) {
      
      if fieldIndex < self.fields.count-1 {
        self.fields[fieldIndex + 1].becomeFirstResponder()
      }
      else {
        self.fields[fieldIndex].resignFirstResponder()
      }
      
    }
    
    return true
  }
  
}
