//
//  SettingsVC.swift
//  Trampigo
//
//  Created by Naim Ashhab on 24.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit

final class SettingsVC: UIViewController {
  
  // MARK: - Outlets
  
  @IBOutlet weak var closeButton: UIButton!
  @IBOutlet weak var header     : UIView!
  @IBOutlet weak var avatarView : UIImageView!
  @IBOutlet weak var name       : UILabel!
  @IBOutlet weak var email      : UILabel!
  
  @IBOutlet weak var tableView: UITableView!
  
  @IBOutlet weak var logoutButton: SlantButton!
  
  
  // MARK: - Property
  // MARK: - Lifecycle
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    setupView()
    self.setNeedsStatusBarAppearanceUpdate()
  }
  
  override func viewWillAppear(animated: Bool) {
    super.viewWillAppear(animated)
    
  }
  
  override func preferredStatusBarStyle() -> UIStatusBarStyle {
    return .LightContent
  }
  
  // MARK: - Actions
  
  @IBAction func logout(sender: AnyObject) {
    
    
    // Action sheet
    
    let alert = UIAlertController(title: "Logout".localized, message: "user-logout-alert".localized, preferredStyle: UIAlertControllerStyle.ActionSheet)
    
    
    // Logout action
    
    let logoutAction = UIAlertAction(title: "Logout".localized, style: UIAlertActionStyle.Destructive) {
      [weak self] (_) -> Void in
      
      User.logout()
      self?.dismissViewController()
      
    }
    
    
    // Cancel action
    
    let cancelAction = UIAlertAction(title: "Cancel".localized, style: UIAlertActionStyle.Cancel, handler: nil)
    
    
    alert.addAction(logoutAction)
    alert.addAction(cancelAction)
    
    
    // Present action sheet
    
    self.presentViewController(alert, animated: true, completion: nil)
  }
  
  
  // MARK: - Selectors
  // MARK: - Private
  
  func setupView() {
    
    // Header
    
    setupHeader()
    
    
    // Button
    
    logoutButton.setTitle("Logout".localized, forState: .Normal)
    logoutButton.backgroundColor = UIColor.trampigoPrimaryColor()
    
    
    // Table view
    
    tableView.dataSource = self
    tableView.delegate = self
    tableView.tableFooterView = UIView()
    tableView.registerNib(UINib(nibName: "UserCell", bundle: nil), forCellReuseIdentifier: UserCell.reuseIdentifier)
    tableView.registerNib(UINib(nibName: "TrendCell", bundle: nil), forCellReuseIdentifier: TrendCell.reuseIdentifier)
    tableView.contentInset = UIEdgeInsets(top: 0, left: 0, bottom: logoutButton.frame.height, right: 0)
    tableView.scrollIndicatorInsets = UIEdgeInsets(top: 0, left: 0, bottom: logoutButton.frame.height, right: 0)
    
    
    // Info
    
    if let user = User.logedUser {
      name.text = user.fullName
      email.text = user.email
    }
    else {
      self.dismissViewController()
    }
    
  }
  
  func setupHeader() {
    
    // Avatar
    
    avatarView.layer.cornerRadius = avatarView.frame.height / 2
    avatarView.layer.borderColor = UIColor.whiteColor().CGColor
    avatarView.layer.borderWidth = 3
    avatarView.clipsToBounds = true
    avatarView.backgroundColor = UIColor.lightGrayColor()
    
    
    // Slant header
    
    let headerFrame = header.frame
    
    let slantLayer = CAShapeLayer()
    slantLayer.frame = headerFrame
    
    let slantPath = UIBezierPath()
    slantPath.moveToPoint(CGPoint(x: 0, y: 0))
    slantPath.addLineToPoint(CGPoint(x: CGRectGetWidth(headerFrame), y: 0))
    slantPath.addLineToPoint(CGPoint(x: CGRectGetWidth(headerFrame), y: CGRectGetHeight(headerFrame) - 20))
    slantPath.addLineToPoint(CGPoint(x: 0, y: CGRectGetHeight(headerFrame)))
    slantPath.closePath()
    
    slantLayer.path = slantPath.CGPath
    
    header.layer.mask = slantLayer
    header.layer.masksToBounds = true
    header.backgroundColor = UIColor.trampigoPrimaryColor()
    
    
    // Close button
    
    closeButton.tintColor = UIColor.whiteColor()
    
  }
  
}


// MARK: - Table view data source

extension SettingsVC: UITableViewDataSource {
  
  func numberOfSectionsInTableView(tableView: UITableView) -> Int {
    return 1
  }
  
  func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
    
    let gymnastsCount = (User.logedUser as? Coach)?.gymnasts.count ?? 0
    
    if section > 0 {
      return 3
    } else if isCoachTarget && gymnastsCount > 0 {
      return gymnastsCount
    } else {
      return 1
    }
    
  }
  
  func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
    
    if indexPath.section == 0 {
      
      let cell = tableView.dequeueReusableCellWithIdentifier(UserCell.reuseIdentifier, forIndexPath: indexPath) as! UserCell
      
      if isGymnastTarget {
        cell.setUser((User.logedUser as? Gymnast)?.coach)
      } else {
        
        let coach = User.logedUser as? Coach
        if coach?.gymnasts.count > 0 {
          cell.setUser(coach?.gymnasts[indexPath.row])
        } else {
          cell.setUser(nil)
        }
        
      }
      
      return cell
      
    } else {
      
      let cell = tableView.dequeueReusableCellWithIdentifier(TrendCell.reuseIdentifier, forIndexPath: indexPath) as! TrendCell
      
      // TODO: Set trends data
      
      return cell
    }
    
  }
  
}


// MARK: - Table view delegate

extension SettingsVC: UITableViewDelegate {
  
  func tableView(tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
    
    if section > 0 {
      return "Other".localized
    } else {
      return isGymnastTarget ? "Coach".localized : "Gymnasts".localized
    }
    
  }
  
  func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
    if indexPath.section == 0 && indexPath.row == 0 && isGymnastTarget {
      
      guard let _ = (User.logedUser as? Gymnast)?.coach else {
        return self.performSegueWithIdentifier(SettingsSegue.UserSearch.rawValue, sender: nil)
      }
      
    }
    
    tableView.deselectRowAtIndexPath(indexPath, animated: true)
  }
  
  func tableView(tableView: UITableView, willDisplayHeaderView view: UIView, forSection section: Int) {
    
    if view is UITableViewHeaderFooterView {
      let headerView = view as! UITableViewHeaderFooterView
      headerView.contentView.backgroundColor = UIColor.whiteColor()
      headerView.textLabel?.textColor = UIColor.lightGrayColor()
    }
    
  }
  
}
