//
//  NewRoundVC.swift
//  Trampigo
//
//  Created by Naim Ashhab on 10.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit

final class NewRoundVC: UIViewController {
  
  // MARK: - Outlets
  
  @IBOutlet weak var headerLabel: UILabel!
  
  @IBOutlet weak var skillsTextField  : NumberField!
  @IBOutlet weak var diffTextField    : NumberField!
  
  @IBOutlet weak var skillsLabel  : UILabel!
  @IBOutlet weak var diffLabel    : UILabel!
  
  @IBOutlet weak var addButton  : SlantButton!
  
  // MARK: - Property
  
  var roundNumber: Int = 0
  var initialValues: (skills: Int, difficulty: Double) = (0, 0.0)
  var onReturn: ((skills: Int, difficulty: Double) -> Void)!
  
  // MARK: - Lifecycle
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    setupView()
  }
  
  override func viewWillAppear(animated: Bool) {
    super.viewWillAppear(animated)
    
    registerForSocketConnectionNotifications(connectionChangedSelector: "socketConnectionStatusChanged:")
  }
  
  override func viewWillDisappear(animated: Bool) {
    super.viewWillDisappear(animated)
    
    NSNotificationCenter.defaultCenter().removeObserver(self)
  }
  
  override func prefersStatusBarHidden() -> Bool {
    return true
  }
  
  // MARK: - Actions
  
  @IBAction func addRound(sender: AnyObject) {
    if let skills = Int(skillsTextField.text!), let difficulty = Double(diffTextField.text!) where skills > 0 && difficulty > 0 {
      onReturn(skills: skills, difficulty: difficulty)
    }
  }
  
  @IBAction func tapOnView(sender: AnyObject) {
    skillsTextField.resignFirstResponder()
    diffTextField.resignFirstResponder()
  }
  
  
  // MARK: - Selectors
  
  func socketConnectionStatusChanged(notification: NSNotification) {
    setupViewForSocketState(connected: Emitter.isSocketConnected)
  }
  
  // MARK: - Private
  
  private func setupView() {
    
    // Fields
    
    skillsTextField.delegate = self
    diffTextField.delegate = self
    
    skillsTextField.color = UIColor.trampigoSkillsColor()
    diffTextField.color   = UIColor.trampigoDifficultyColor()
    
    skillsTextField.text = initialValues.skills != 0 ? "\(initialValues.skills)" : nil
    diffTextField.text = initialValues.difficulty != 0 ? String(format: "%.1f", initialValues.difficulty) : nil
    
    
    // Header
    
    let attributedHeader = NSMutableAttributedString(string: "\(roundNumber). ", attributes: [NSFontAttributeName: UIFont.systemFontOfSize(24)])
    attributedHeader.appendAttributedString(NSAttributedString(string: "round".localized, attributes: [NSFontAttributeName: UIFont(name: ".SFUIDisplay-Thin", size: 24)!]))
    headerLabel.attributedText = attributedHeader
    
    
    // Socket state
    
    setupViewForSocketState(connected: Emitter.isSocketConnected)
  }
  
  private func setupViewForSocketState(connected connected: Bool) {
    addButton.enabled = connected
  }
  
}

extension NewRoundVC: UITextFieldDelegate {
  
  func textField(textField: UITextField, shouldChangeCharactersInRange range: NSRange, replacementString string: String) -> Bool {
    
    let currentText = textField.text ?? ""
    let prospectiveText = (currentText as NSString).stringByReplacingCharactersInRange(range, withString: string)
    
    // Only numbers
    if let _ = prospectiveText.rangeOfString("^[/.0-9]*$", options: .RegularExpressionSearch) {
      
      if textField == diffTextField {
        let currentValue = Double(currentText) ?? 0.0
        let prospectiveValue = Double(prospectiveText) ?? 0.0
        
        if prospectiveValue == 0 {
          textField.text = nil
        }
        else if currentText == "" || string == "" {
          textField.text = String(format: "%.1f", prospectiveValue / 10)
        }
        else if currentValue <= prospectiveValue && string != "" {
          textField.text = String(format: "%.1f", prospectiveValue * 10)
        }
        
        return false
      }
      
      return true
    }
    
    return false
  }
  
}
