//
//  TrainingList.swift
//  Trampigo
//
//  Created by Naim Ashhab on 20.12.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit

final class TrainingListVC: UIViewController {
  
  // MARK: - Outlets
  
  @IBOutlet weak var customNavigationBar: UIView!
  @IBOutlet weak var customNavigationBarTitle: UILabel!
  
  @IBOutlet weak var trainingListTableView: UITableView!
  
  // MARK: - Property
  
  var trainings = [Training]()
  
  // MARK: - Lifecycle
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    trainingListTableView.registerNib(UINib(nibName: "TrainingTableCell", bundle: nil), forCellReuseIdentifier: TrainingTableCell.reuseIdentifier)
    trainingListTableView.dataSource = self
    trainingListTableView.delegate = self
    trainingListTableView.rowHeight = 120
    trainingListTableView.tableFooterView = UIView()
    
    self.setNeedsStatusBarAppearanceUpdate()
    
    customNavigationBar.backgroundColor = UIColor.trampigoPrimaryColor()
    
    trainings = [Training]()
    
    var gymnastIds = [String]()
    if let gymnast = User.logedUser as? Gymnast {
      gymnastIds.append(gymnast.id)
    } else if let coach = User.logedUser as? Coach {
      
      for gymnast in coach.gymnasts {
        gymnastIds.append(gymnast.id)
      }
      
    }
    
    for gymnastId in gymnastIds {
      Emitter.downloadGymnastTrainingsInTimeRange(gymnastId: gymnastId, inTimeRange: TimeRange(rangeDays: 90, daysToPast: 0), callback: {
        (_, _, gymnastTrainings, error) -> Void in
        
        for training in gymnastTrainings {
          self.trainings.append(training)
        }
        
        self.trainings = self.trainings.sort({$0.date > $1.date})
        
        self.trainingListTableView.reloadSections(NSIndexSet(index: 0), withRowAnimation: UITableViewRowAnimation.Middle)
      })
    }
    
  }
  
  override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
    if segue.identifier == TrainingListSegue.TrainingDetail.rawValue {
      
      if let training = sender as? Training {
        let vc = segue.destinationViewController as! TrainingVC
        vc.training = training
        vc.inProgress = false
      }
      
    }
  }
  
  override func preferredStatusBarStyle() -> UIStatusBarStyle {
    return .LightContent
  }
  
  // MARK: - Actions
  // MARK: - Selectors
  // MARK: - Private

}

extension TrainingListVC: UITableViewDataSource {
  
  func numberOfSectionsInTableView(tableView: UITableView) -> Int {
    return 1
  }
  
  func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
    return trainings.count
  }
  
  func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
    
    let cell = tableView.dequeueReusableCellWithIdentifier(TrainingTableCell.reuseIdentifier, forIndexPath: indexPath) as! TrainingTableCell
    
    cell.setTraining(trainings[indexPath.row])
    
    if indexPath.row % 2 == 1 {
      cell.backgroundColor = UIColor.trampigoPrimaryColor().colorWithAlphaComponent(0.05)
    }
    
    return cell
  }
  
}

extension TrainingListVC: UITableViewDelegate {
  
  func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
    
    tableView.deselectRowAtIndexPath(indexPath, animated: true)
    performSegueWithIdentifier(TrainingListSegue.TrainingDetail.rawValue, sender: trainings[indexPath.row])
    
  }
  
}

