//
//  TrainingTableCell.swift
//  Trampigo
//
//  Created by Naim Ashhab on 20.12.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit

final class TrainingTableCell: UITableViewCell {
  
  static var reuseIdentifier = "TrainingTableCell"
  
  @IBOutlet weak var dayLabel: UILabel!
  @IBOutlet weak var durationLabel: UILabel!
  
  @IBOutlet weak var roundsValueView: ValueView!
  @IBOutlet weak var difficultyValueView: ValueView!
  @IBOutlet weak var skillsValueView: ValueView!
  @IBOutlet weak var difficultyOnSkillValueView: ValueView!
  
  @IBOutlet weak var gymnastAvatarView: UIImageView!
  
  override func awakeFromNib() {
    super.awakeFromNib()
    
    roundsValueView.color = UIColor.trampigoRoundsColor()
    difficultyValueView.color = UIColor.trampigoDifficultyColor()
    skillsValueView.color = UIColor.trampigoSkillsColor()
    difficultyOnSkillValueView.color = UIColor.trampigoDifficultyPerSkillColor()
    
    roundsValueView.backgroundColor = UIColor.clearColor()
    difficultyValueView.backgroundColor = UIColor.clearColor()
    skillsValueView.backgroundColor = UIColor.clearColor()
    difficultyOnSkillValueView.backgroundColor = UIColor.clearColor()
    
    gymnastAvatarView.layer.cornerRadius = gymnastAvatarView.frame.height / 2
    gymnastAvatarView.clipsToBounds = true
    gymnastAvatarView.hidden = true
  }
  
  func setTraining(training: Training) {
    
    dayLabel.text = training.date.date()
    durationLabel.text = "\(training.duration) min"
    
    if training.owner.id == User.logedUser.id {
      gymnastAvatarView.hidden = true
    } else {
      gymnastAvatarView.hidden = false
      gymnastAvatarView.image = UIImage(named: "avatar-naim")
    }
    
    roundsValueView.value = Double(training.roundsCount ?? 0)
    difficultyValueView.value = training.difficulty
    skillsValueView.value = Double(training.skills ?? 0)
    difficultyOnSkillValueView.value = training.difficultyPerSkill
  }
  
}
