//
//  GymnastTableCell.swift
//  Trampigo
//
//  Created by Naim Ashhab on 06.12.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit
import MGSwipeTableCell

class GymnastTableCell: MGSwipeTableCell {
  
  static var reuseIdentifier = "GymnastTableCell"
  
  @IBOutlet private weak var avatar: UIImageView!
  @IBOutlet private weak var nameLabel: UILabel!
  
  @IBOutlet private weak var trainingValueView  : ValueView!
  @IBOutlet private weak var avgRoundsValueView : ValueView!
  @IBOutlet private weak var avgSkillsValueView : ValueView!
  @IBOutlet private weak var avgDiffValueView   : ValueView!
  @IBOutlet private weak var runningTrainingView: UIView!
  
  var isRunningTraining: Bool {
    get {
      return _isRunningTraining
    }
    set {
      _isRunningTraining = newValue
      runningTrainingView.backgroundColor =  _isRunningTraining ? UIColor.greenColor() : UIColor.clearColor()
    }
  }
  
  var gymnast: User!
  
  private var _isRunningTraining: Bool = false
  
  override func awakeFromNib() {
    super.awakeFromNib()
    
    // Labels
    
    trainingValueView.label   = "trainings"
    avgRoundsValueView.label  = "avg. rounds"
    avgSkillsValueView.label  = "avg. skills"
    avgDiffValueView.label    = "avg. diff"
    
    
    // Label bottom inset
    
    let customLabelInset: CGFloat = 3
    trainingValueView.labelBottomInset  = customLabelInset
    avgRoundsValueView.labelBottomInset = customLabelInset
    avgSkillsValueView.labelBottomInset = customLabelInset
    avgDiffValueView.labelBottomInset   = customLabelInset
    
    
    // Decimal
    
    avgSkillsValueView.showDecimals = true
    avgDiffValueView.showDecimals   = true
    
    
    // Default name
    
    nameLabel.text = ""
    
    
    // Avatar 
    
    avatar.layer.cornerRadius = avatar.frame.height/2
    avatar.clipsToBounds = true
    avatar.backgroundColor = UIColor.lightGrayColor()
  }
  
  func setGymnast(gymnast: User!) {
    
    self.gymnast = gymnast
    
    nameLabel.text = gymnast?.fullName ?? "No gymnast"
    avatar.image = UIImage(named: "avatar-naim")
    // TODO: set avatar image
  }
  
  func setGymnastQuickAnalyse(basicAnalysis: BasicTrainingAnalysis?, upToDate: Bool = true) {
    
    // Values
    
    trainingValueView.value   = basicAnalysis?.trainings ?? 0
    avgRoundsValueView.value  = basicAnalysis?.avgRounds ?? 0
    avgSkillsValueView.value  = basicAnalysis?.avgSkillsInRound ?? 0
    avgDiffValueView.value    = basicAnalysis?.avgSkillDiff ?? 0
    
    
    // Up-To-Date
    
    trainingValueView.upToDate  = upToDate
    avgRoundsValueView.upToDate = upToDate
    avgSkillsValueView.upToDate = upToDate
    avgDiffValueView.upToDate   = upToDate
    
  }
  
}
