//
//  TrainingChartView.swift
//  Trampigo
//
//  Created by Naim Ashhab on 11.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit
import Charts

final class TrainingChartView: LineChartView {
  
  var training: Training! {
    didSet {
      update()
    }
  }
  
  var showingAnyProperty: Bool {
    return showSkills || showDifficulty || showDifficultyPerSkill
  }
  
  var showSkills              : Bool = true
  var showDifficulty          : Bool = false
  var showDifficultyPerSkill  : Bool = true
  
  func update() {
    clear()
    if let data = createChartData() {
      self.data = data
    }
  }
  
  func defaultChartSetup() {
    
    noDataText = "Make at least 2 rounds to see training chart...".localized
    infoTextColor = UIColor.trampigoPrimaryColor()
    descriptionText = ""
    rightAxis.enabled = false
    leftAxis.enabled = false
    xAxis.enabled = false
    legend.enabled = false
    drawGridBackgroundEnabled = false
    highlightPerTapEnabled = false
    highlightPerDragEnabled = false
    drawBordersEnabled = false
    scaleYEnabled = false
    scaleXEnabled = true
    
  }
  
  private func createChartData() -> ChartData? {
    
    if training.rounds.count < 2 {
      return nil
    }
    
    var dataSets = [LineChartDataSet]()
    
    let properties = Round.propertyList
    
    for i in 0..<3 {
      
      if (i == 0 && !showSkills) || (i == 1 && !showDifficulty) || (i == 2 && !showDifficultyPerSkill) {
        continue
      }
      
      
      var dataEntries = [ChartDataEntry]()
      for (index, round) in training.rounds.enumerate() {
        dataEntries.append(ChartDataEntry(value: round.doubleForPropertyName(properties[i])!, xIndex: index))
      }
      
      
      let dataSet = LineChartDataSet(yVals: dataEntries, label: nil)
      
      // Line draw
      dataSet.colors = [Round.colorForPropertyName(properties[i])!.colorWithAlphaComponent(0.8)]
      dataSet.drawCubicEnabled = true
      
      // Space under the line
      dataSet.drawFilledEnabled = true
      dataSet.fillAlpha = 0.8
      dataSet.fillColor = Round.colorForPropertyName(properties[i])!
      
      // Value circles
      dataSet.circleRadius = 5.0
      dataSet.valueTextColor = UIColor.blackColor()
      dataSet.setCircleColor(Round.colorForPropertyName(properties[i])!)
      dataSet.drawCircleHoleEnabled = false
      dataSet.drawValuesEnabled = true
      
      dataSets.append(dataSet)
    }
    
    
    var xVals = [String]()
    for i in 1...training.rounds.count {
      xVals.append("\(i)")
    }
    
    return LineChartData(xVals: xVals, dataSets: dataSets)
  }
  
}
