//
//  SlantButton.swift
//  Trampigo
//
//  Created by Naim Ashhab on 03.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit

@IBDesignable
final class SlantButton: UIButton {
  
  // MARK: - Constants
  
  @IBInspectable var slantDelta: Int = 20
  @IBInspectable var customTitleEdgeInset: Bool = false
  @IBInspectable var slantBottom: Bool = false
  
  var indicatingActivity: Bool = false {
    didSet {
      if indicatingActivity {
        title = titleLabel?.text
        setTitle("", forState: .Normal)
        activityIndicator = UIActivityIndicatorView(activityIndicatorStyle: .White)
        activityIndicator.startAnimating()
        activityIndicator.center = CGPoint(x: frame.size.width/2, y: (frame.size.height + CGFloat(slantDelta/2))/2)
        self.addSubview(activityIndicator!)
        userInteractionEnabled = false
      }
      else {
        activityIndicator?.removeFromSuperview()
        setTitle(title, forState: .Normal)
        userInteractionEnabled = true
      }
    }
  }
  
  private var title: String?
  private var activityIndicator: UIActivityIndicatorView!
  private let slantLayer = CAShapeLayer()
  
  override var enabled: Bool {
    didSet {
      alpha = enabled ? 1.0 : 0.5
    }
  }
  
  override func drawRect(rect: CGRect) {
    slantLayer.frame = rect
    
    let slantPath = UIBezierPath()
    slantPath.moveToPoint(CGPoint(x: 0, y: slantDelta))
    slantPath.addLineToPoint(CGPoint(x: CGRectGetWidth(rect), y: 0))
    slantPath.addLineToPoint(CGPoint(x: CGRectGetWidth(rect), y: CGRectGetHeight(rect) - (slantBottom ? CGFloat(slantDelta) : 0)))
    slantPath.addLineToPoint(CGPoint(x: 0, y: CGRectGetHeight(rect)))
    slantPath.closePath()
    
    slantLayer.path = slantPath.CGPath
    
    self.layer.mask = slantLayer
    
    if !customTitleEdgeInset && !slantBottom {
      self.titleEdgeInsets.top = CGFloat(slantDelta / 2)
    }
    
  }
  
  // MARK: - Errors
  
  func showErrorMessage(message: String, duration: NSTimeInterval = 2) {
    
  }
  
}
