//
//  ValueView.swift
//  Trampigo
//
//  Created by Naim Ashhab on 06.11.15.
//  Copyright © 2015 Naim Ashhab. All rights reserved.
//

import UIKit

@IBDesignable
final class ValueView: UIView {
  
  let valueLabel = UILabel()
  let labelLabel = UILabel()

  var value: Double = 0.0 {
    didSet {
      updateValueLabel()
    }
  }
  
  @IBInspectable var showDecimals: Bool = false
  @IBInspectable var numberOfDecimals: Int = 1
  @IBInspectable var label: String = ""
  @IBInspectable var color: UIColor = UIColor.blackColor()
  @IBInspectable var valueFontSize: CGFloat = 30
  @IBInspectable var labelBottomInset: CGFloat = 8
  @IBInspectable var upToDate: Bool = true {
    didSet {
      valueLabel.textColor = upToDate ? color : color.colorWithAlphaComponent(0.4)
    }
  }
  
  override func drawRect(rect: CGRect) {
    setupValueLabelInRect(rect)
    setupLabelLabelInRect(rect)
    
    updateValueLabel()
  }
  
  private func setupValueLabelInRect(rect: CGRect) {
    valueLabel.font = UIFont.systemFontOfSize(valueFontSize)
    labelLabel.sizeToFit()
    self.addSubview(valueLabel)
    valueLabel.center = CGPoint(x: CGRectGetMidX(rect), y: CGRectGetMidY(rect) * 0.8)
    valueLabel.textColor = upToDate ? color : color.colorWithAlphaComponent(0.7)
  }
  
  private func setupLabelLabelInRect(rect: CGRect) {
    labelLabel.text = label
    labelLabel.font = UIFont.systemFontOfSize(10)
    labelLabel.sizeToFit()
    self.addSubview(labelLabel)
    labelLabel.center = CGPoint(x: rect.midX, y: rect.height - labelLabel.frame.height/2 - labelBottomInset)
    labelLabel.textColor = color
  }
  
  private func updateValueLabel() {
    if value != 0 && !value.isNaN {
      valueLabel.text = String(format: (showDecimals ? "%.\(numberOfDecimals)f" : "%.0f"), value)
    } else {
      valueLabel.text = "---"
    }
    
    valueLabel.sizeToFit()
    valueLabel.center = CGPoint(x: CGRectGetMidX(bounds), y: CGRectGetMidY(bounds))
  }

}
