//
//  TimeRangeTest.swift
//  Trampigo
//
//  Created by Naim Ashhab on 13.01.16.
//  Copyright © 2016 Naim Ashhab. All rights reserved.
//

import XCTest

class TimeRangeTest: XCTestCase {
  
  private let dayTimeInterval: NSTimeInterval = 86400
  
  func testDaysPresent() {
    let days = TimeRange(rangeDays: 2, daysToPast: 0).toDateArray()
    
    XCTAssert(days.count == 2)
    XCTAssert(days.last?.dayDate() == NSDate().dayDate())
    XCTAssert(days.first?.dayDate() == NSDate().dateByAddingTimeInterval(-dayTimeInterval).dayDate())
  }
  
  func testDaysPast() {
    let days = TimeRange(rangeDays: 4, daysToPast: 1).toDateArray()
    
    XCTAssert(days.count == 4)
    XCTAssert(days.last!.dayDate()! < NSDate().dayDate()!)
    XCTAssert(days.last!.dayDate() == NSDate().dateByAddingTimeInterval(-dayTimeInterval).dayDate())
  }
  
  func testSetDaysToPast() {
    var range = TimeRange(rangeDays: 2, daysToPast: 0)
    
    XCTAssert(range.to.dayDate() == NSDate().dayDate())
    XCTAssert(range.from.dayDate() == NSDate().dateByAddingTimeInterval(-dayTimeInterval).dayDate())
    
    range.setDaysToPast(2)
    XCTAssert(range.to.dayDate() == NSDate().dateByAddingTimeInterval(-2*dayTimeInterval).dayDate())
    XCTAssert(range.from.dayDate() == NSDate().dateByAddingTimeInterval(-3*dayTimeInterval).dayDate())
    
    range.setDaysToPast(0)
    XCTAssert(range.to.dayDate() == NSDate().dayDate())
    XCTAssert(range.from.dayDate() == NSDate().dateByAddingTimeInterval(-dayTimeInterval).dayDate())
  }
  
  func testSetTimeRange() {
    var range = TimeRange(rangeDays: 2, daysToPast: 0)
    
    XCTAssert(range.from.dayDate() == NSDate().dateByAddingTimeInterval(-dayTimeInterval).dayDate())
    
    range.setDayRange(1)
    XCTAssert(range.from.dayDate() == NSDate().dayDate())
    
    range.setDayRange(5)
    XCTAssert(range.from.dayDate() == NSDate().dateByAddingTimeInterval(-4*dayTimeInterval).dayDate())
  }
  
}
