//
//  TrainingAnalysisTest.swift
//  Trampigo
//
//  Created by Naim Ashhab on 13.01.16.
//  Copyright © 2016 Naim Ashhab. All rights reserved.
//

import XCTest
import SwiftyJSON

class TrainingAnalysisTest: XCTestCase {
  
  var analysis: TrainingAnalysis!
  
  private func createTraining(roundsJSON: [[String: AnyObject]]) -> Training {
    let trainingJSON = [
      "owner" : ["id": "testID", "fullName": "test name", "email": "test email"],
      "date" : 1452684646,
      "id" : "test id 1234",
      "finished" : true,
      "duration" : 14,
      "rounds" : roundsJSON
    ]
    
    let training = Training(json: JSON(trainingJSON))!
    training.date = NSDate()
    
    return training
  }
  
  override func setUp() {
    super.setUp()
    
    var trainings = [Training]()
    
    trainings.append(createTraining([
      ["id" : "1", "skills" : 10, "difficulty" : 1],
      ["id" : "2", "skills" : 5, "difficulty" : 10],
      ["id" : "3", "skills" : 8, "difficulty" : 1]
    ]))
    trainings.append(createTraining([
      ["id" : "1", "skills" : 5, "difficulty" : 16]
    ]))
    
    analysis = TrainingAnalysis(objects: trainings)
  }
  
  func testBasicAnalysis() {
    
    let basic = analysis.basicAnalysis
    
    XCTAssert(basic.trainings == 2)
    XCTAssert(basic.avgRounds == 2)
    XCTAssert(basic.avgSkillDiff == 1)
    XCTAssert(basic.avgSkillsInRound == 7)
  }
  
  func testPropertyDuration() {
    
    let durations = analysis.analyseProperty(.Duration, inTimeRange: TimeRange(rangeDays: 2, daysToPast: 0))
    
    XCTAssert(durations.count == 2)
    XCTAssert(durations.last == 28)
    XCTAssert(durations.first == 0)
  }
  
  func testPropertyTotalRounds() {
    
    let rounds = analysis.analyseProperty(.TotalRounds, inTimeRange: TimeRange(rangeDays: 2, daysToPast: 0))
    
    XCTAssert(rounds.count == 2)
    XCTAssert(rounds.last == 4)
    XCTAssert(rounds.first == 0)
  }
  
  func testPropertyTotalSkills() {
    
    let skills = analysis.analyseProperty(.TotalSkills, inTimeRange: TimeRange(rangeDays: 3, daysToPast: 0))
    
    XCTAssert(skills.count == 3)
    XCTAssert(skills.last == 28)
    XCTAssert(skills.first == 0)
  }
  
  func testPropertyTotalDifficulty() {
    
    let difficulty = analysis.analyseProperty(.TotalDifficulty, inTimeRange: TimeRange(rangeDays: 3, daysToPast: 0))
    
    XCTAssert(difficulty.count == 3)
    XCTAssert(difficulty.last == 28)
    XCTAssert(difficulty.first == 0)
  }
  
  func testPropertyAvgDifficultyOnSkill() {
    
    let diffSkill = analysis.analyseProperty(.AvgDifficultyOnSkill, inTimeRange: TimeRange(rangeDays: 3, daysToPast: 0))
    
    XCTAssert(diffSkill.count == 3)
    XCTAssert(diffSkill.last == 1)
    XCTAssert(diffSkill.first == 0)
  }
  
  func testPropertyAvgSkillsInRound() {
    
    let skillsRound = analysis.analyseProperty(.AvgSkillsInRound, inTimeRange: TimeRange(rangeDays: 3, daysToPast: 0))
    
    XCTAssert(skillsRound.count == 3)
    XCTAssert(skillsRound.last == 7)
    XCTAssert(skillsRound.first == 0)
  }
    
}
