//
//  TrainingEntityAnalysableAdapterTest.swift
//  Trampigo
//
//  Created by Naim Ashhab on 13.01.16.
//  Copyright © 2016 Naim Ashhab. All rights reserved.
//

import XCTest
import SwiftyJSON

class TrainingEntityAnalysableAdapterTest: XCTestCase {
  
  var training: Training!
  
  override func setUp() {
    super.setUp()
    // Put setup code here. This method is called before the invocation of each test method in the class.
    
    let trainingJSON = JSON([
      "owner" : ["id": "testID", "fullName": "test name", "email": "test email"],
      "date" : 1452684646,
      "id" : "test id 1234",
      "finished" : true,
      "duration" : 14,
      "rounds" : [
        ["id" : "1", "skills" : 10, "difficulty" : 1],
        ["id" : "2", "skills" : 4, "difficulty" : 10],
        ["id" : "3", "skills" : 10, "difficulty" : 1]
      ]
      ])
    
    training = Training(json: trainingJSON)!
  }
  
  override func tearDown() {
    // Put teardown code here. This method is called after the invocation of each test method in the class.
    super.tearDown()
  }
  
  func testRoundsCount() {
    XCTAssert(training.roundsCount == 3)
    
    training.rounds.append(Round(skills: 2, difficulty: 1))
    XCTAssert(training.roundsCount == 4)
    
    training.rounds.removeAtIndex(0)
    XCTAssert(training.roundsCount == 3)
    
    training.rounds.removeLast()
    XCTAssert(training.roundsCount == 2)
  }
  
  func testSkills() {
    XCTAssert(training.skills == 24)
    
    training.rounds.append(Round(skills: 3, difficulty: 1))
    XCTAssert(training.skills == 27)
    
    training.rounds.removeAtIndex(0)
    XCTAssert(training.skills == 17)
    
    training.rounds.removeLast()
    XCTAssert(training.skills == 14)
  }
  
  func testDifficulty() {
    XCTAssert(training.difficulty == 12)
    
    training.rounds.append(Round(skills: 2, difficulty: 4.4))
    XCTAssert(training.difficulty == 16.4)
    
    training.rounds.removeAtIndex(0)
    XCTAssert(training.difficulty == 15.4)
    
    training.rounds.removeLast()
    XCTAssert(training.difficulty == 11)
  }
  
  func testDifficultyPerSkill() {
    XCTAssert(training.difficultyPerSkill == 0.5)
    
    training.rounds.append(Round(skills: 6, difficulty: 18))
    XCTAssert(training.difficultyPerSkill == 1)
    
    training.rounds[0].skills = 40
    XCTAssert(training.difficultyPerSkill == 0.5)
  }
  
  func testSkillsInRound() {
    XCTAssert(training.skillsInRound == 8)
    
    training.rounds.append(Round(skills: 6, difficulty: 4.4))
    XCTAssert(training.skillsInRound == 7.5)
    
    training.rounds[0].skills = 18
    XCTAssert(training.skillsInRound == 9.5)
  }
  
}
