//
//  TrainingEntityTest.swift
//  Trampigo
//
//  Created by Naim Ashhab on 13.01.16.
//  Copyright © 2016 Naim Ashhab. All rights reserved.
//

import XCTest
import SwiftyJSON

class TrainingEntityJSONAdapterTest: XCTestCase {
  
  func testTrainingAdapterValidJSON() {
    
    let trainingJSON = JSON([
      "owner" : ["id": "testID", "fullName": "test name", "email": "test email"],
      "date" : 1452684646,
      "id" : "test id 1234",
      "finished" : true,
      "duration" : 14,
      "rounds" : [
        ["id" : "1", "skills" : 10, "difficulty" : 1],
        ["id" : "2", "skills" : 5, "difficulty" : 10],
        ["id" : "3", "skills" : 10, "difficulty" : 1]
      ]
    ])
    
    guard let training = Training(json: trainingJSON) else {
      return XCTAssert(false)
    }
    
    XCTAssert(training.owner is Gymnast)
    XCTAssert(training.owner.id == "testID")
    XCTAssert(training.owner.fullName == "test name")
    XCTAssert(training.owner.email == "test email")
    
    XCTAssert(training.id == "test id 1234")
    XCTAssert(training.finished == true)
    XCTAssert(training.duration == 14)
    XCTAssert(training.date != nil)
    
    XCTAssert(training.rounds.count == 3)
    XCTAssert(training.rounds[0].skills == 10)
    XCTAssert(training.rounds[1].difficulty == 10)
  }
  
  func testTrainingAdapterInvalidJSON() {
    
    if let _ = Training(json: JSON([])) {
      XCTAssert(false)
    }
    if let _ = Training(json: JSON("invalid")) {
      XCTAssert(false)
    }
    
    
    var trainingJSON = JSON([
      "owner" : ["id": "testID", "fullName": "test name", "email": "test email"],
      "date" : 1452684646,
//      "id" : "test id 1234",
      "finished" : true,
      "duration" : 14,
      "rounds" : [
        ["id" : "1", "skills" : 10, "difficulty" : 1],
        ["id" : "2", "skills" : 5, "difficulty" : 10],
        ["id" : "3", "skills" : 10, "difficulty" : 1]
      ]
    ])
    
    if let _ = Training(json: trainingJSON) {
      XCTAssert(false)
    }
    
    
    trainingJSON = JSON([
      "owner" : ["id": "testID", "fullName": "test name", "email": "test email"],
      "date" : 1452684646,
      "id" : "test id 1234",
//      "finished" : true,
      "duration" : 14,
      "rounds" : [
        ["id" : "1", "skills" : 10, "difficulty" : 1],
        ["id" : "2", "skills" : 5, "difficulty" : 10],
        ["id" : "3", "skills" : 10, "difficulty" : 1]
      ]
    ])
    
    if let _ = Training(json: trainingJSON) {
      XCTAssert(false)
    }
    
    
    trainingJSON = JSON([
      "owner" : ["id": "testID", "fullName": "test name", "email": "test email"],
      "date" : 1452684646,
      "id" : "test id 1234",
      "finished" : true,
//      "duration" : 14,
      "rounds" : [
        ["id" : "1", "skills" : 10, "difficulty" : 1],
        ["id" : "2", "skills" : 5, "difficulty" : 10],
        ["id" : "3", "skills" : 10, "difficulty" : 1]
      ]
    ])
    
    if let _ = Training(json: trainingJSON) {
      XCTAssert(false)
    }
    
    
    trainingJSON = JSON([
      "owner" : ["id": "testID", "fullName": "test name", "email": "test email"],
      "date" : 1452684646,
      "id" : "test id 1234",
      "finished" : true,
      "duration" : 14
    ])
    
    guard let _ = Training(json: trainingJSON) else {
      return XCTAssert(false)
    }
    
  }
  
}
